@@ -24,16 +24,18 @@ VirtualBox nodes, networks and volumes.
 """
 
 import os
+import re
+import subprocess
 import sys
 
-from libcloud.compute import providers
+from libcloud.compute import providers as compute_providers
 from libcloud import security
 
 try:
-    import nose
-    NOSE_FOUND = True
+    import pytest
+    PYTEST_FOUND = True
 except ImportError:
-    NOSE_FOUND = False
+    PYTEST_FOUND = False
 
 try:
     import netifaces
@@ -44,25 +46,30 @@ try:
 except ImportError:
     NETIFACES_FOUND = False
 
-from libcloudvagrant.driver import VAGRANT, VagrantDriver, __name__ as pkg_name
+from libcloudvagrant.common.types import VAGRANT
+from libcloudvagrant.compute import driver as compute_driver
 
 
 __all__ = [
     "__version__",
+    "VAGRANT",
     "test",
 ]
 
 
-providers.set_driver(VAGRANT, pkg_name, VagrantDriver.__name__)
+compute_providers.set_driver(VAGRANT,
+                             compute_driver.__name__,
+                             compute_driver.VagrantDriver.__name__)
 
 security.CA_CERTS_PATH.append(os.path.join(os.path.dirname(__file__),
+                                           "common",
                                            "ca-bundle.crt"))
 
 
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 
 
-def test():
+def test():  # pragma: no cover
     """Runs the tests for ``libcloud-vagrant``.
 
     Requires ``nose`` to be installed. The tests take quite a bit of time to
@@ -71,8 +78,8 @@ def test():
 
     """
     can_run = True
-    if not NOSE_FOUND:
-        print >> sys.stderr, "Install 'nose' in order to run the tests."
+    if not PYTEST_FOUND:
+        print >> sys.stderr, "Install 'pytest' in order to run the tests."
         can_run = False
 
     if not NETIFACES_FOUND:
@@ -81,4 +88,44 @@ def test():
 
     if can_run:
         print "Testing libcloud-vagrant %s" % (__version__,)
-        return nose.run(__name__)
+        return pytest.main([__name__])
+
+
+def execute(cmdline):
+    p = subprocess.Popen(cmdline,
+                         shell=True,
+                         stdout=subprocess.PIPE,
+                         stderr=subprocess.STDOUT)
+    stdout, _ = p.communicate()
+    if p.returncode:
+        raise RuntimeError("Cannot execute '%s': %s", cmdline, stdout)
+    return stdout.strip()
+
+
+def check_versions():
+    """Verifies the versions of VirtualBox, Vagrant and the required Vagrant
+    plugins.
+
+    """
+    vagrant_version = execute("vagrant --version")
+    if not vagrant_version.startswith("Vagrant 1.6"):
+        raise RuntimeError("Unsupported %s" % (vagrant_version,))
+
+    virtualbox_version = execute("VBoxManage --version")
+    if not virtualbox_version.startswith("4.3"):
+        raise RuntimeError("Unsupported VirtualBox %s" %
+                           (virtualbox_version,))
+
+    vagrant_plugins = execute("vagrant plugin list")
+    m = re.search(r"vagrant-libcloud-helper \((.+?)\)", vagrant_plugins)
+    if not m:
+        print >> sys.stderr, "Installing plugin 'vagrant-libcloud-helper'"
+        execute("vagrant plugin update vagrant-libcloud-helper")
+    else:
+        required = "0.0.2"
+        if m.group(1) != required:
+            print >> sys.stderr, "Updating plugin 'vagrant-libcloud-helper'"
+            execute("vagrant plugin update vagrant-libcloud-helper")
+
+
+check_versions()
