@@ -21,7 +21,6 @@
 """Unit test support code."""
 
 import logging
-import tempfile
 import uuid
 
 from contextlib import contextmanager
@@ -29,31 +28,22 @@ from contextlib import contextmanager
 import ipaddr
 import netifaces
 
-from libcloud.compute import providers
-
-from libcloudvagrant.driver import VAGRANT
-
 
 __all__ = [
-    "available_private_network",
-    "new_driver",
+    "available_network",
     "sample_network",
     "sample_node",
     "sample_volume",
 ]
 
 
-import libcloudvagrant.driver
-libcloudvagrant.driver._HOME = tempfile.mkdtemp(prefix="libcloudvagrant-home-")
-
-
 LOG = logging.getLogger("libcloudvagrant")
 
 
 ALLOCATED_NETWORKS = set()
 
 
-def available_private_network():
+def available_network():
     """Returns the first available 24-bit available network in the range of
     the 256 networks in the block 192.168/16.
 
@@ -71,22 +61,15 @@ def available_private_network():
     raise Exception("No available 24-bit network in the block 192.168/16")
 
 
-def new_driver():
-    """Returns a new instance of the Vagrant compute driver.
-
-    """
-    return providers.get_driver(VAGRANT)()
-
-
 @contextmanager
-def sample_network(name, cidr=None, public=False):
+def sample_network(driver, name=None, cidr=None, public=False):
     """Context manager which creates a new network before starting, and
     destroys it after leaving.
 
     """
-    d = new_driver()
-    cidr = cidr or str(available_private_network())
-    network = d.ex_create_network(name, cidr, public)
+    name = name or uuid.uuid4().hex
+    cidr = cidr or str(available_network())
+    network = driver.ex_create_network(name, cidr, public)
     try:
         yield network
     finally:
@@ -94,22 +77,21 @@ def sample_network(name, cidr=None, public=False):
             ALLOCATED_NETWORKS.remove(str(network))
         except KeyError:
             pass
-        d.ex_destroy_network(network)
+        driver.ex_destroy_network(network)
 
 
 @contextmanager
-def sample_node(name=None, networks=None, size=None):
+def sample_node(driver, name=None, networks=None, size=None):
     """Context manager which creates a new node before starting, and destroys
     it after leaving.
 
     The node is based on the ``hashicorp/precise64`` Vagrant image.
 
     """
-    d = new_driver()
-    node = d.create_node(name=name or uuid.uuid4().hex,
-                         size=size or d.list_sizes()[0],
-                         image=d.get_image("hashicorp/precise64"),
-                         ex_networks=networks or [])
+    node = driver.create_node(name=name or uuid.uuid4().hex,
+                              size=size or driver.list_sizes()[0],
+                              image=driver.get_image("hashicorp/precise64"),
+                              ex_networks=networks or [])
     try:
         yield node
     finally:
@@ -117,16 +99,16 @@ def sample_node(name=None, networks=None, size=None):
 
 
 @contextmanager
-def sample_volume(name=None):
+def sample_volume(driver, name=None):
     """Context manager which creates a new 1 GB volume before starting, and
     destroys it after leaving.
 
     """
-    d = new_driver()
-    volume = d.create_volume(name=name or uuid.uuid4().hex, size=1)
+    volume = driver.create_volume(name=name or uuid.uuid4().hex, size=1)
     try:
         yield volume
     finally:
+        driver.detach_volume(volume)
         volume.destroy()
 
 
