@@ -22,9 +22,9 @@
 
 import uuid
 
-from libcloud.compute.deployment import ScriptDeployment
+from contextlib import contextmanager
 
-from libcloudvagrant.tests import new_driver, sample_network
+from libcloud.compute.deployment import ScriptDeployment
 
 
 __all__ = [
@@ -35,17 +35,15 @@ __all__ = [
 ]
 
 
-driver = new_driver()
-
-
-def test_deploy_without_network():
+def test_deploy_without_network(driver):
     """Deployment works for nodes without networks.
 
     """
-    deploy_node(networks=[])
+    with deploy_node(driver, networks=[]):
+        pass
 
 
-def test_http_proxy():
+def test_http_proxy(driver):
     """Deploying behind an HTTP proxy works.
 
     """
@@ -53,46 +51,44 @@ def test_http_proxy():
     echo "Hello from $(hostname)"
     wget -O - https://github.com/carletes/libcloud-vagrant
     """
-    result = deploy_node(script=script)
-    assert ("you could prototype a small cluster" in result)
+    with deploy_node(driver, script=script) as result:
+        assert ("you could prototype a small cluster" in result)
 
 
-def test_with_private_network():
+def test_with_private_network(driver, private_network):
     """Deployment works for nodes with private networks.
 
     """
-    with sample_network("priv", public=False) as net:
-        deploy_node(networks=[net])
+    with deploy_node(driver, networks=[private_network]):
+        pass
 
 
-def test_with_public_network():
+def test_with_public_network(driver, public_network):
     """Deployment works for nodes with public networks.
 
     """
-    with sample_network("priv", public=True) as net:
-        deploy_node(networks=[net])
+    with deploy_node(driver, networks=[public_network]):
+        pass
 
 
-def deploy_node(networks=None, script=None):
+@contextmanager
+def deploy_node(driver, networks=None, script=None):
     script = script or """#!/bin/sh
 
     echo "Hello from $(hostname)"
     """
     script = ScriptDeployment(script)
     name = uuid.uuid4().hex
-    image = driver.get_image("hashicorp/precise64")
-    node = None
+    node = driver.deploy_node(name=name,
+                              image=driver.get_image("hashicorp/precise64"),
+                              size=driver.list_sizes()[0],
+                              ex_networks=networks,
+                              deploy=script)
     try:
-        node = driver.deploy_node(name=name,
-                                  image=image,
-                                  size=driver.list_sizes()[0],
-                                  ex_networks=networks,
-                                  deploy=script)
         assert node.name == name
         assert script.exit_status == 0, script.stderr
         expected = "Hello from %s" % (node.name,)
         assert (expected in script.stdout), script.stdout
-        return script.stdout
+        yield script.stdout
     finally:
-        if node is not None:
-            driver.destroy_node(node)
+        driver.destroy_node(node)
