@@ -20,8 +20,7 @@
 
 """Unit tests for data types."""
 
-from libcloudvagrant.tests import new_driver
-from libcloudvagrant.types import (
+from libcloudvagrant.compute.types import (
     VagrantAddress,
     VagrantImage,
     VagrantNetwork,
@@ -37,9 +36,6 @@ __all__ = [
 ]
 
 
-driver = new_driver()
-
-
 def test_serializable():
     """Serializable types can be converted to and from their dict
     representations.
@@ -47,36 +43,39 @@ def test_serializable():
     """
     assert_serializable(VagrantAddress,
                         {"address": "10.0.0.1", "network_name": "net1"})
-    assert_serializable(VagrantNetwork,
-                        {
-                            "name": "net1",
-                            "cidr": "10.0.0.0/8",
-                            "public": True,
-                            "allocated": [],
-                            "host_interface": "vboxnet4",
-                        },
-                        {
-                            "name": "net1",
-                            "cidr": "10.0.0.0/8",
-                            "public": True,
-                            "allocated": [
-                                "10.0.0.1",
-                                "10.0.0.2",
-                            ],
-                            "host_interface": None,
-                        })
 
 
-def test_serializable_with_driver():
+def test_serializable_with_driver(driver):
     """Serializable types can be converted to and from their dict
     representations.
 
     """
-    assert_serializable_with_driver(VagrantImage,
+    assert_serializable_with_driver(driver,
+                                    VagrantImage,
                                     {
                                         "name": "ubuntu/trusty64",
                                     })
-    assert_serializable_with_driver(VagrantNode,
+    assert_serializable_with_driver(driver,
+                                    VagrantNetwork,
+                                    {
+                                        "name": "net1",
+                                        "cidr": "10.0.0.0/8",
+                                        "public": True,
+                                        "allocated": [],
+                                        "host_interface": "vboxnet4",
+                                    },
+                                    {
+                                        "name": "net1",
+                                        "cidr": "10.0.0.0/8",
+                                        "public": True,
+                                        "allocated": [
+                                            "10.0.0.1",
+                                            "10.0.0.2",
+                                        ],
+                                        "host_interface": None,
+                                    })
+    assert_serializable_with_driver(driver,
+                                    VagrantNode,
                                     {
                                         "id": "27036b03-13a1-45d6-9030-a3faef699ba9",
                                         "name": "node1",
@@ -88,6 +87,7 @@ def test_serializable_with_driver():
                                             "cpus": 3,
                                         },
                                         "image": {"name": "ubuntu/trusty64"},
+                                        "allocate_sata_ports": 30,
                                     },
                                     {
                                         "id": "361f2550-bc23-4eca-ad22-49914dd8b530",
@@ -110,14 +110,17 @@ def test_serializable_with_driver():
                                             "cpus": 2,
                                         },
                                         "image": {"name": "ubuntu/trusty64"},
+                                        "allocate_sata_ports": 30,
                                     })
-    assert_serializable_with_driver(VagrantNodeSize,
+    assert_serializable_with_driver(driver,
+                                    VagrantNodeSize,
                                     {
                                         "name": "default",
                                         "ram": 2048,
                                         "cpus": 2,
                                     })
-    assert_serializable_with_driver(VagrantVolume,
+    assert_serializable_with_driver(driver,
+                                    VagrantVolume,
                                     {
                                         "name": "test-volume",
                                         "size": 42,
@@ -145,7 +148,7 @@ def assert_serializable(cls, *params):
         assert recreated == obj
 
 
-def assert_serializable_with_driver(cls, *params):
+def assert_serializable_with_driver(driver, cls, *params):
     """Serializable types can be converted to and from their dict
     representations.
 
