@@ -23,7 +23,7 @@
 import uuid
 
 from libcloud.compute.types import NodeState
-from libcloudvagrant.tests import new_driver, sample_node, sample_volume
+from libcloudvagrant.tests import sample_node, sample_volume
 
 
 __all__ = [
@@ -31,53 +31,69 @@ __all__ = [
     "test_attach_volume",
     "test_create_volume",
     "test_destroy_volume",
+    "test_destroy_node_detaches_volume",
+    "test_detach_unattached",
     "test_invalid_device",
-    "test_list_volumes",
     "test_move_volume",
 ]
 
 
-driver = new_driver()
-
-
-def test_attach_to_device():
+def test_attach_to_device(driver, node):
     """It is possible to attach volumes to specific devices.
 
     """
-    with sample_node() as node, sample_volume() as v1, sample_volume() as v2:
+    with sample_volume(driver) as v1, sample_volume(driver) as v2:
         assert driver.attach_volume(node, v1, device="/dev/sdc")
         assert not driver.attach_volume(node, v2, device="/dev/sdc")
         assert driver.attach_volume(node, v2, device="/dev/sdb")
 
 
-def test_attach_volume():
+def test_attach_volume(driver, node, volume):
     """Volumes may be hot-plugged to nodes.
 
     """
-    with sample_node() as node, sample_volume() as volume:
-        assert node.state == NodeState.RUNNING
-        assert volume.attached_to is None
+    assert node.state == NodeState.RUNNING
+    assert volume.attached_to is None
+    assert driver.attach_volume(node, volume)
+    assert volume.attached_to == node.name
+
+
+def test_destroy_node_detaches_volume(driver, volume):
+    """Destroying a node detaches all volumes attached to it.
+
+    """
+    with sample_node(driver) as node:
         assert driver.attach_volume(node, volume)
         assert volume.attached_to == node.name
 
+    assert get_volume(driver, volume.name).attached_to == None
 
-def test_move_volume():
+
+def test_detach_unattached(driver, volume):
+    """Detaching has no effect on unattached nodes.
+
+    """
+    assert volume.attached_to == None
+    assert driver.detach_volume(volume)
+
+
+def test_move_volume(driver, node, volume):
     """Attached volumes may be detached and attached to anothe node.
 
     """
-    with sample_node() as n1, sample_node() as n2, sample_volume() as v:
-        assert driver.attach_volume(n1, v)
-        assert v.attached_to == n1.name
-        assert not driver.attach_volume(n2, v)
+    with sample_node(driver) as other_node:
+        assert driver.attach_volume(node, volume)
+        assert volume.attached_to == node.name
+        assert not driver.attach_volume(other_node, volume)
 
-        assert driver.detach_volume(v)
-        assert v.attached_to is None
-        assert driver.attach_volume(n2, v)
-        assert v.attached_to == n2.name
-        assert not driver.attach_volume(n1, v)
+        assert driver.detach_volume(volume)
+        assert volume.attached_to is None
+        assert driver.attach_volume(other_node, volume)
+        assert volume.attached_to == other_node.name
+        assert not driver.attach_volume(node, volume)
 
 
-def test_create_volume():
+def test_create_volume(driver):
     """Created volumes are correctly registered.
 
     """
@@ -86,49 +102,36 @@ def test_create_volume():
 
     size = 42
     volume = driver.create_volume(size=size, name=test_volume)
-    assert volume.name == test_volume
-    assert volume.size == size
-    assert volume in driver.list_volumes()
+    try:
+        assert volume.name == test_volume
+        assert volume.size == size
+        assert volume in driver.list_volumes()
+    finally:
+        driver.destroy_volume(volume)
 
 
-def test_destroy_volume():
+def test_destroy_volume(driver):
     """Attached volumes may not be destroyed.
 
     """
-    volume = get_volume("test-volume")
+    volume = driver.create_volume(name="test-volume", size=1)
     volume.attached_to = "some-node"
     assert not driver.destroy_volume(volume)
 
-    volume = get_volume("test-volume")
     volume.attached_to = None
     assert driver.destroy_volume(volume)
     assert volume not in driver.list_volumes()
 
 
-def test_invalid_device():
+def test_invalid_device(driver, node, volume):
     """Volumes may only be attached to ``/dev/sd[a-z]``.
 
     """
-    with sample_node() as node, sample_volume() as volume:
-        assert not driver.attach_volume(node, volume, "/dev/sdB")
-        assert driver.attach_volume(node, volume, "/dev/sdb")
+    assert not driver.attach_volume(node, volume, "/dev/sdB")
+    assert driver.attach_volume(node, volume, "/dev/sdb")
 
 
-def test_list_volumes():
-    """Volumes are registered correctly.
-
-    """
-    with sample_volume():
-        for volume in driver.list_volumes():
-            assert volume.driver == driver
-
-
-def get_volume(name):
-    """Returns the specified volume, creating a 1 GB volume if it does not
-    already exist.
-
-    """
+def get_volume(driver, name):
     for v in driver.list_volumes():
         if v.name == name:
             return v
-    return driver.create_volume(size=42, name=name)
